.. pyphasefield documentation master file, created by
   sphinx-quickstart on Fri Apr  2 11:44:15 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyphasefield's documentation!
========================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:
   
   installation
   usage/script_template
   usage/diffusion
   usage/engine_template
   usage/boundaries
   technical/gpu_functions



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
